=== modified file 'plugin/user_locks/get_lock.cc'
--- plugin/user_locks/get_lock.cc	2011-03-16 21:57:41 +0000
+++ plugin/user_locks/get_lock.cc	2011-03-16 23:21:18 +0000
@@ -47,34 +47,26 @@
   if (list) // To be compatible with MySQL, we will now release all other locks we might have.
     list->erase_all();
 
-  bool result;
   drizzled::identifier::User::const_shared_ptr user_identifier(getSession().user());
   {
     boost::this_thread::restore_interruption dl(getSession().getThreadInterupt());
 
-    try {
-      result= user_locks::Locks::getInstance().lock(getSession().getSessionId(), Key(*user_identifier, res->c_str()), wait_time);
+    try 
+    {
+      if (not user_locks::Locks::getInstance().lock(getSession().getSessionId(), Key(*user_identifier, res->c_str()), wait_time))
+        return 0;
     }
-    catch(boost::thread_interrupted const& error)
+    catch (boost::thread_interrupted const&)
     {
       my_error(drizzled::ER_QUERY_INTERRUPTED, MYF(0));
       null_value= true;
-
       return 0;
     }
   }
-
-  if (result)
-  {
-    if (not list)
-      list= getSession().setProperty("user_locks", new user_locks::Storable(getSession().getSessionId()));
-
-    list->insert(Key(*user_identifier, res->c_str()));
-
-    return 1;
-  }
-
-  return 0;
+  if (not list)
+    getSession().setProperty("user_locks", new user_locks::Storable(getSession().getSessionId()));
+  list->insert(Key(*user_identifier, res->c_str()));
+  return 1;
 }
 
 } /* namespace user_locks */

=== modified file 'plugin/user_locks/get_locks.cc'
--- plugin/user_locks/get_locks.cc	2011-03-16 21:57:41 +0000
+++ plugin/user_locks/get_locks.cc	2011-03-16 23:21:18 +0000
@@ -44,41 +44,28 @@
       return 0;
     }
   }
-
-  bool result;
   {
     boost::this_thread::restore_interruption dl(getSession().getThreadInterupt());
-
-    try {
-      result= user_locks::Locks::getInstance().lock(getSession().getSessionId(), list_of_locks);
+    try 
+    {
+      if (not user_locks::Locks::getInstance().lock(getSession().getSessionId(), list_of_locks))
+        return 0;
     }
-    catch(boost::thread_interrupted const& error)
+    catch (boost::thread_interrupted const&)
     {
       my_error(drizzled::ER_QUERY_INTERRUPTED, MYF(0));
       null_value= true;
-
       return 0;
     }
   }
 
-  if (result)
-  {
-    user_locks::Storable *list= getSession().getProperty<user_locks::Storable>("user_locks");
-    if (not list)
-      list= getSession().setProperty("user_locks", new user_locks::Storable(getSession().getSessionId()));
-
-    for (Keys::iterator iter= list_of_locks.begin();
-         iter != list_of_locks.end(); iter++)
-    {
-      list->insert(*iter);
-    }
-
-    null_value= false;
-
-    return 1;
-  }
-
-  return 0;
+  user_locks::Storable *list= getSession().getProperty<user_locks::Storable>("user_locks");
+  if (not list)
+    list= getSession().setProperty("user_locks", new user_locks::Storable(getSession().getSessionId()));
+  BOOST_FOREACH(Keys::const_reference iter, list_of_locks)
+    list->insert(iter);
+  null_value= false;
+  return 1;
 }
 
 } /* namespace user_locks */

